package ch.zhaw.projekt2.turnierverwaltung.main.participantAddFormular;

import ch.zhaw.projekt2.turnierverwaltung.FXController;
import ch.zhaw.projekt2.turnierverwaltung.Participant;
import ch.zhaw.projekt2.turnierverwaltung.Player;
import ch.zhaw.projekt2.turnierverwaltung.Tournament;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.ListView;
import javafx.scene.control.TextField;
import javafx.scene.input.MouseEvent;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.VBox;

import java.util.logging.Logger;

/**
 * Controller of Participant
 */
public class ParticipantFormularController extends FXController {

    @FXML
    private Button addBtn;

    @FXML
    private Label birthDateLabel;

    @FXML
    private TextField birthDateTextField;

    @FXML
    private VBox changeBtn;

    @FXML
    private Label firstNameLabel;

    @FXML
    private TextField firstNameTextField;

    @FXML
    private GridPane grid;

    @FXML
    private Label newParticipantFormularTitle;

    @FXML
    private Button closeBtn;

    @FXML
    private Button deleteBtn;


    @FXML
    private Label participantListTitle;

    @FXML
    private ListView<Participant> participantListView;

    @FXML
    private Label participantNameLabel;

    @FXML
    private TextField participantNameTextField;

    @FXML
    private Label phoneNumberLabel;

    @FXML
    private TextField phoneNumberTextField;

    @FXML
    private Button saveBtn;

    private static final Logger logger = Logger.getLogger(ParticipantFormularController.class.getCanonicalName());

    /**
     * Shares GUI Elements with the LanguageConfigurator
     */
    @Override
    public void shareGUIElementWithLanguageConfigurator() {
        logger.fine("sharing GUI Elements");
        getLanguageConfigurator().recieveLabel(participantListTitle);
        getLanguageConfigurator().recieveLabel(closeBtn);
        getLanguageConfigurator().recieveLabel(deleteBtn);
        getLanguageConfigurator().recieveLabel(newParticipantFormularTitle);
        getLanguageConfigurator().recieveLabel(participantNameLabel);
        getLanguageConfigurator().recieveLabel(firstNameLabel);
        getLanguageConfigurator().recieveLabel(phoneNumberLabel);
        getLanguageConfigurator().recieveLabel(birthDateLabel);
        getLanguageConfigurator().recieveLabel(saveBtn);
    }

    /**
     * Changes the current selection
     */
    @FXML
    void changedSelection(){
        Player participant = (Player) participantListView.getSelectionModel().getSelectedItems().get(0);
        participantNameTextField.setText(participant.getName());
        firstNameTextField.setText(participant.getFirstName());
        phoneNumberTextField.setText(participant.getPhoneNumber());
        birthDateTextField.setText(participant.getFormattedDateOfBirth());
    }

    /**
     * Saves a new Participant and clears form
     */
    @FXML
    void saveParticipant() {
        getTournamentDecorator().savePlayer(firstNameTextField.getText(), participantNameTextField.getText(), phoneNumberTextField.getText(), birthDateTextField.getText());
        clearFormular();
    }

    /**
     * Clears current form
     */
    private void clearFormular() {
        firstNameTextField.clear();
        participantNameTextField.clear();
        phoneNumberTextField.clear();
        birthDateTextField.clear();
    }

    /**
     * Deletes the selected participant.
     */
    @FXML
    void delete() {
        Participant participant = participantListView.getSelectionModel().getSelectedItems().get(0);
        logger.fine("deleting participant:" + participant);
        getTournamentDecorator().deleteParticipant(participant);
    }

    /**
     * Closes the participant form
     */
    @FXML
    void close() {
        getFactoryDecorator().openScheduleView();
    }

    /**
     * Loads the previously saved content and puts it in the list
     */
    @Override
    public void loadContent() {
        logger.fine("loading and placing it into the list");
        Tournament tournament = getTournamentDecorator().getTournament();
        if(tournament != null){
            participantListView.setItems(tournament.getParticipants());
        } else {
            participantListView.getItems().clear();
        }
    }
}
